#
# Copyright (c) 2008-2019 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'

from persistent import Persistent
from zope.container.contained import Contained
from zope.schema.fieldproperty import FieldProperty

from pyams_content.component.links import InternalReferenceMixin
from pyams_content.features.search.interfaces import ISearchManagerInfo
from pyams_content.root import ISiteRoot
from pyams_utils.adapter import adapter_config, get_annotation_adapter
from pyams_utils.factory import factory_config

SEARCH_MANAGER_INFO_KEY = 'pyams_content.search'


@factory_config(ISearchManagerInfo)
class SearchManagerInfo(Persistent, Contained, InternalReferenceMixin):
    """Search manager persistent info"""

    name = FieldProperty(ISearchManagerInfo['name'])
    description = FieldProperty(ISearchManagerInfo['description'])


@adapter_config(context=ISiteRoot, provides=ISearchManagerInfo)
def site_root_search_manager_adapter(context):
    """Site root search manager adapter"""
    return get_annotation_adapter(context, SEARCH_MANAGER_INFO_KEY, ISearchManagerInfo)
